DashboardPosition enum

Position for the dashboard overlay.

Inheritance
Available extensions

Values

topLeft → const DashboardPosition

Top-left corner.

topRight → const DashboardPosition

Top-right corner.

bottomLeft → const DashboardPosition

Bottom-left corner.

bottomRight → const DashboardPosition

Bottom-right corner.

center → const DashboardPosition

Center of the screen.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DashboardPosition>
A constant List of the values in this enum, in order of their declaration.