MetricsSnapshot class

An immutable snapshot of performance metrics at a point in time.

Constructors

MetricsSnapshot({required double fps, required double averageBuildTimeMs, required double averageRasterTimeMs, required double averageFrameTimeMs, required double memoryUsageMB, required double peakMemoryUsageMB, required int totalRebuilds, required int jankFrames, required int warningCount, required int setStateCalls, required int maxWidgetDepth, required DateTime timestamp})
Creates a MetricsSnapshot.
const

Properties

averageBuildTimeMs double
Average build time in ms.
final
averageFrameTimeMs double
Average total frame time in ms.
final
averageRasterTimeMs double
Average raster time in ms.
final
fps double
Frames per second.
final
hashCode int
The hash code for this object.
no setterinherited
jankFrames int
Total jank frames.
final
maxWidgetDepth int
Max widget depth measured.
final
memoryUsageMB double
Current memory usage in MB.
final
peakMemoryUsageMB double
Peak memory usage in MB.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setStateCalls int
Total setState calls.
final
timestamp DateTime
When the snapshot was taken.
final
totalRebuilds int
Total rebuilds counted.
final
warningCount int
Number of warnings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited